@@ -133,7 +133,7 @@ bool KDesktopFile::isAuthorizedDesktopFile(const QString &path)
             return true;
         }
     }
-    const QString servicesDir = QLatin1String("kde5/services/"); // KGlobal::dirs()->xdgDataRelativePath("services")
+    const QString servicesDir = QLatin1String("kservices5/"); // KGlobal::dirs()->xdgDataRelativePath("services")
     Q_FOREACH (const QString &xdgDataPrefix, QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation)) {
         if (QDir(xdgDataPrefix).exists()) {
             const QString prefix = QFileInfo(xdgDataPrefix).canonicalFilePath();
@@ -202,8 +202,10 @@ QString KDesktopFile::readGenericName() const
 QString KDesktopFile::readPath() const
 {
     Q_D(const KDesktopFile);
-    // NOT readPathEntry, it is not XDG-compliant. Path entries written by
-    // KDE4 will be still treated as such, though.
+    // NOT readPathEntry, it is not XDG-compliant: it performs
+    // various expansions, like $HOME.  Note that the expansion
+    // behaviour still happens if the "e" flag is set, maintaining
+    // backwards compatibility.
     return d->desktopGroup.readEntry("Path", QString());
 }
 
@@ -328,10 +330,6 @@ KDesktopFile::sortOrder() const
 QString KDesktopFile::readDocPath() const
 {
     Q_D(const KDesktopFile);
-    //legacy entry in kde3 apps
-    if (d->desktopGroup.hasKey("DocPath")) {
-        return d->desktopGroup.readPathEntry("DocPath", QString());
-    }
     return d->desktopGroup.readPathEntry("X-DocPath", QString());
 }
 
